pub enum StackRequest {
AddForwardingEntry {
entry: ForwardingEntry,
responder: StackAddForwardingEntryResponder,
},
DelForwardingEntry {
entry: ForwardingEntry,
responder: StackDelForwardingEntryResponder,
},
SetDhcpClientEnabled {
id: u64,
enable: bool,
responder: StackSetDhcpClientEnabledResponder,
},
BridgeInterfaces {
interfaces: Vec<u64>,
bridge: ServerEnd<ControlMarker>,
control_handle: StackControlHandle,
},
}Variants
AddForwardingEntry
Add a new entry to the forwarding table.
If the table already contains an entry with the same subnet and destination, an already exists error is returned.
DelForwardingEntry
Removes the forwarding entry. The entry must exactly match an entry in the forwarding table, with the exception of the metric value, which is ignored.
SetDhcpClientEnabled
Enables or disables the DHCP client on an interface. TODO(https://fxbug.dev/42162065): Remove this once the DHCP client is moved out of the netstack.
BridgeInterfaces
Creates a bridge over the provided interfaces.
If the bridge can’t be created, bridge is closed with a BAD_PORT
termination reason.
NOTE: We’re shoehorning bridging into the admin/Control API and
reassigning meaning to BAD_PORT because we don’t want to leak
bridging-specific errors there. The POR is that bridging is going to get
its own API at some point.
Bridge lifetime is controlled through the bridge handle.
Implementations
Sourceimpl StackRequest
impl StackRequest
pub fn into_add_forwarding_entry( self, ) -> Option<(ForwardingEntry, StackAddForwardingEntryResponder)>
pub fn into_del_forwarding_entry( self, ) -> Option<(ForwardingEntry, StackDelForwardingEntryResponder)>
pub fn into_set_dhcp_client_enabled( self, ) -> Option<(u64, bool, StackSetDhcpClientEnabledResponder)>
pub fn into_bridge_interfaces( self, ) -> Option<(Vec<u64>, ServerEnd<ControlMarker>, StackControlHandle)>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL